/*****************************************************************************
 * ipaspeaker.cpp - QStarDict, a dictionary application for learning         *
 *                  languages                                                *
 * Copyright (C) 2025 Alexander Rodin                                        *
 *                                                                           *
 * This program is free software; you can redistribute it and/or modify      *
 * it under the terms of the GNU General Public License as published by      *
 * the Free Software Foundation; either version 2 of the License, or         *
 * (at your option) any later version.                                       *
 *                                                                           *
 * This program is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 * GNU General Public License for more details.                              *
 *                                                                           *
 * You should have received a copy of the GNU General Public License along   *
 * with this program; if not, write to the Free Software Foundation, Inc.,   *
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.               *
 *****************************************************************************/

#include "ipaspeaker.h"

#include <QVector>
#include "speaker.h"
#include "ipa.h"

namespace QStarDict
{

IpaSpeaker::IpaSpeaker()
{
    m_espeakSpeaker = new Speaker();
}

IpaSpeaker::~IpaSpeaker()
{
    delete m_espeakSpeaker;
}

void IpaSpeaker::speak(const QString &transcription)
{
    const static QVector<QRegularExpression> transcriptionRegExps = {
        Ipa::broadTranscriptionRegExp(),
        Ipa::narrowTranscriptionRegExp()
    };
    QString ipa;
    for (const QRegularExpression &transcriptionRegExp: transcriptionRegExps)
    {
        QString captured = transcriptionRegExp.match(transcription).captured(2);
        if (! captured.isNull())
        {
            ipa = captured;
            break;
        }
    }
    QString kirshenbaum = Ipa::ipaToKirshenbaum(ipa);
    m_espeakSpeaker->speak("[[" + kirshenbaum + "]]");
}

}

